@@ -30,10 +30,9 @@
 #include <sys/time.h>
 #include <stdlib.h>
 
-#define PLUGIN_NAME "livewp-home-widget.desktop-0"
-#define GCONF_KEY_POSITION "/apps/osso/hildon-desktop/applets/%s/position"
-#define GCONF_KEY_MODIFIED "/apps/osso/hildon-desktop/applets/%s/modified"
-#define GCONF_KEY_VIEW     "/apps/osso/hildon-desktop/applets/%s/view"
+#define GCONF_KEY_POSITION "/apps/osso/hildon-desktop/applets/livewp-home-widget.desktop-%i/position"
+#define GCONF_KEY_MODIFIED "/apps/osso/hildon-desktop/applets/livewp-home-widget.desktop-%i/modified"
+#define GCONF_KEY_VIEW     "/apps/osso/hildon-desktop/applets/livewp-home-widget.desktop-%i/view"
 
 HD_DEFINE_PLUGIN_MODULE (AWallpaperPlugin, animation_wallpaper_plugin, HD_TYPE_HOME_PLUGIN_ITEM)
 #define Animation_Wallpaper_HOME_PLUGIN_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE (obj,\
@@ -42,14 +41,29 @@ HD_DEFINE_PLUGIN_MODULE (AWallpaperPlugin, animation_wallpaper_plugin, HD_TYPE_H
 static void
 lw_applet_realize (GtkWidget *widget)
 {
-      GdkScreen *screen;
+    GdkScreen *screen;
+    gchar * strid; 
+    gint id; 
+    AWallpaperPlugin *desktop_plugin = widget;
 
-      screen = gtk_widget_get_screen (widget);
-      gtk_widget_set_colormap (widget,
+    strid = g_strdup(hd_plugin_item_get_plugin_id (HD_PLUGIN_ITEM (widget)));
+    id = strid[strlen(strid)-1] - '0';
+    desktop_plugin->priv->view = id;
+    g_free(strid); 
+    
+    /* Load config */
+    read_config(desktop_plugin->priv);
+
+    init_scene_theme(desktop_plugin);
+        
+    desktop_plugin->priv->long_timer = g_timeout_add(LONG_TIMER, (GtkFunction)long_timeout, desktop_plugin);
+
+    screen = gtk_widget_get_screen (widget);
+    gtk_widget_set_colormap (widget,
                                 gdk_screen_get_rgba_colormap (screen));
-      gtk_widget_set_app_paintable (widget,
+    gtk_widget_set_app_paintable (widget,
                                 TRUE);
-      GTK_WIDGET_CLASS (animation_wallpaper_plugin_parent_class)->realize (widget);
+    GTK_WIDGET_CLASS (animation_wallpaper_plugin_parent_class)->realize (widget);
 }
 
 
@@ -110,36 +124,46 @@ init_applet_position(gint *xapplet, gint *yapplet)
   gchar *modified_key;
   gchar *modified;
   GError *error = NULL;
+  gint i;
   GConfClient   *gconf_client = gconf_client_get_default ();
-  position_key = g_strdup_printf (GCONF_KEY_POSITION, PLUGIN_NAME);
-  position = gconf_client_get_list (gconf_client,
-                                    position_key,
-                                    GCONF_VALUE_INT,
-                                    NULL);
-  if (position && position->data && position->next->data){
-  	*xapplet = GPOINTER_TO_INT (position->data);
-  	*yapplet = GPOINTER_TO_INT (position->next->data);
-  }else{
-	position = g_slist_prepend (g_slist_prepend (NULL,
-                                      GINT_TO_POINTER (Ystartposition)),
-			              GINT_TO_POINTER (Xstartposition));
-	gconf_client_set_list (gconf_client,
-                               position_key,
-                               GCONF_VALUE_INT,
-	                       position,
-			       &error);
-	*xapplet = Xstartposition;
-	*yapplet = Ystartposition;
+  for (i=0;i<4;i++){
+      position_key = g_strdup_printf (GCONF_KEY_POSITION, i);
+      position = gconf_client_get_list (gconf_client,
+                                        position_key,
+                                        GCONF_VALUE_INT,
+                                        NULL);
+      if (position && position->data && position->next->data){
+        *xapplet = GPOINTER_TO_INT (position->data);
+        *yapplet = GPOINTER_TO_INT (position->next->data);
+      }else{
+        position = g_slist_prepend (g_slist_prepend (NULL,
+                                          GINT_TO_POINTER (Ystartposition)),
+                              GINT_TO_POINTER (Xstartposition));
+        gconf_client_set_list (gconf_client,
+                                   position_key,
+                                   GCONF_VALUE_INT,
+                               position,
+                       &error);
+        *xapplet = Xstartposition;
+        *yapplet = Ystartposition;
+      }
+      g_free (position_key);
+      modified = g_strdup_printf ("%i", 0);
+      modified_key = g_strdup_printf (GCONF_KEY_MODIFIED, i);
+      gconf_client_set_string (gconf_client,
+                               modified_key,
+                               modified,
+                               &error);
+      g_free(modified);
+      g_free(modified_key);
+      modified_key = g_strdup_printf (GCONF_KEY_VIEW, i);
+      gconf_client_set_int (gconf_client,
+                               modified_key,
+                               (i+1),
+                               &error);
+      g_free(modified_key);
+
   }
-  g_free (position_key);
-  modified = g_strdup_printf ("%i", 0);
-  modified_key = g_strdup_printf (GCONF_KEY_MODIFIED, PLUGIN_NAME);
-  gconf_client_set_string (gconf_client,
-                           modified_key,
-                           modified,
-                           &error);
-  g_free(modified);
-  g_free(modified_key);
   gconf_client_clear_cache(gconf_client);
   g_object_unref(gconf_client);
 }
@@ -426,9 +450,7 @@ animation_wallpaper_plugin_init (AWallpaperPlugin *desktop_plugin)
     desktop_plugin->priv =  Animation_Wallpaper_HOME_PLUGIN_GET_PRIVATE (desktop_plugin);
     priv->osso = osso_initialize(PACKAGE, VERSION, TRUE, NULL);
 
-    /* Load config */
-    read_config(priv);
-    /* Initialize DBUS */
+        /* Initialize DBUS */
     livewp_initialize_dbus(priv);
 
     priv->desktop_plugin = desktop_plugin;
@@ -492,9 +514,9 @@ animation_wallpaper_plugin_init (AWallpaperPlugin *desktop_plugin)
     else if (!strcmp(priv->theme, "Matrix"))
         init_scene_Matrix(desktop_plugin);
 #endif
-    init_scene_theme(desktop_plugin);
+//    init_scene_theme(desktop_plugin);
         
-    priv->long_timer = g_timeout_add(LONG_TIMER, (GtkFunction)long_timeout, desktop_plugin);
+//    priv->long_timer = g_timeout_add(LONG_TIMER, (GtkFunction)long_timeout, desktop_plugin);
     /* TODO Move scene to priv */
     //scene.timer_type = LONG_TIMER_TYPE;
     g_signal_connect (desktop_plugin, "notify::is-on-current-desktop",
