@@ -32,7 +32,7 @@ btn_setting_clicked(HildonButton *btn, gpointer data)
     Animation_WallpaperPrivate *priv = data;
     // open settings dialog
     fprintf(stderr, "btn setting clicked, %s\n", priv->theme);
-    lw_settings(priv, NULL);
+    lw_main_settings(priv, NULL);
     fprintf(stderr, "btn setting clicked, %s\n", priv->theme);
 }
 void
