@@ -34,7 +34,7 @@ void lw_about(void){
     gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
     gtk_window_set_modal(GTK_WINDOW(window), TRUE);
     vbox = gtk_vbox_new (FALSE, 5);
-    label_about = gtk_label_new (_("Live Wallpaper\n Version 0.6 \n Copyright(c) 2010\n \
+    label_about = gtk_label_new (_("Live Wallpaper Version 0.6.1 \n Copyright(c) 2010\n \
 Tanya Makova\n Vlad Vasiliev\n \
 Copyright(c) 2010 for design themes Berlin and Modern Vasya Bobrikov\n \
 Copyright(c) 2010 for design theme Matrix Andrew Zhilin\n \
@@ -170,7 +170,7 @@ create_enable_button (gboolean active)
 /*******************************************************************************/
 void
 show_settings(GtkWidget *widget, Animation_WallpaperPrivate *priv){
-    lw_settings(priv, NULL);
+    lw_main_settings(priv, NULL);
 }
 /*******************************************************************************/
 void 
